@@ -584,7 +584,7 @@ impl FileChooser {
                 dir.as_ptr(),
                 pattern.as_ptr(),
                 typ.bits as i32,
-                title.as_ptr(),
+                title.into_raw(),
             );
             assert!(!ptr.is_null());
             FileChooser { inner: ptr }
@@ -843,7 +843,7 @@ impl FileChooser {
     }
 
     /// Returns whether the file chooser is shown
-    pub fn shown(&mut self) -> bool {
+    pub fn shown(&self) -> bool {
         assert!(!self.inner.is_null());
         unsafe { Fl_File_Chooser_shown(self.inner) != 0 }
     }
